package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.dto.ConceptDTO;
import com.diagbot.entity.LibraryInfo;
import com.diagbot.service.impl.LibraryInfoServiceImpl;
import com.diagbot.vo.AmendTermVo;
import com.diagbot.vo.TermVo;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.List;
import java.util.Map;

/**
 * @Description: 术语基本信息查询业务层
 * @author: Weixuan Huang
 * @time: 2019/1/16 14:17
 */
@Component
public class LibraryInfoFacade extends LibraryInfoServiceImpl {

    private DateTimeFormatter df = DateTimeFormatter.ofPattern("yyyy-MM-dd hh:mm:ss");

    /**
     * 获取医学术语基本信息
     *
     * @param termVo
     * @result LibraryInfo
     */
    public LibraryInfo getLibraryInfor(TermVo termVo) {
        QueryWrapper<LibraryInfo> wrapper = new QueryWrapper();
        if (termVo.getConcept_id() != 0) {
            wrapper.eq("concept_id", termVo.getConcept_id());
        }
        if (termVo.getId() != 0) {
            wrapper.eq("id", termVo.getId());
        }
        if (termVo.getTerm() != null) {
            wrapper.eq("name", termVo.getTerm());
        }
        LibraryInfo libraryinfor = this.getOne(wrapper);
        return libraryinfor;
    }


    /**
     * 更新或添加医学术语基本信息
     *
     * @param amendTermVo
     * @return LibraryInfo
     */
    public LibraryInfo upsertLibraryInfo(AmendTermVo amendTermVo) {

        String oldterm = amendTermVo.getOldterm();
        String newterm = amendTermVo.getNewterm();
        String concept = amendTermVo.getConcept();
        int concept_id = amendTermVo.getConcept_id();

        TermVo termVo = new TermVo();
        termVo.setTerm(concept);

        LibraryInfo conceptInfo = this.getLibraryInfor(termVo);

        termVo.setTerm(newterm);
        LibraryInfo libraryInfo = getLibraryInfor(termVo);

        // 如果术语概念存在，而且新术语不存在
        if (libraryInfo == null) {

            // 如果原先术语名称为空，则添加新术语
            if (oldterm.trim().length() == 0 && newterm.trim().length() > 0) {
                libraryInfo = new LibraryInfo();
                libraryInfo.setGmtCreate(LocalDateTime.now());
            }
            // 原先的术语名称不为空，则修改原先的术语
            else if (oldterm.trim().length() > 0 && !oldterm.trim().equals(newterm.trim())) {
                termVo.setTerm(oldterm);
                libraryInfo = getLibraryInfor(termVo);
                libraryInfo.setGmtModified(LocalDateTime.now());
            }

            libraryInfo.setName(newterm);
        }

        if (conceptInfo != null) {
            libraryInfo.setConceptId(concept_id);

            if (newterm.trim().equals(concept.trim())) {
                libraryInfo.setIsConcept(1);
            }
        }

        this.saveOrUpdate(libraryInfo);

        return libraryInfo;
    }
}
