package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.dto.TypeDTO;
import com.diagbot.entity.Medical;
import com.diagbot.service.impl.MedicalServiceImpl;
import com.diagbot.vo.AmendTermVo;
import com.diagbot.vo.MedicalVo;
import com.diagbot.vo.TermVo;
import com.diagbot.vo.TypeVo;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;

/**
 * @Description: 术语临床信息查询业务层
 * @author: Weixuan Huang
 * @time: 2019/1/16 16:07
 */
@Component
public class MedicalFacade extends MedicalServiceImpl {

    /**
     * 获取医学术语知识
     *
     * @param medicalVo
     * @result List<Medical>
     */
    public List<Medical> getMedicalInfo(MedicalVo medicalVo) {
        QueryWrapper<Medical> wrapper = new QueryWrapper<>();

        if (medicalVo.getName() != null && medicalVo.getName().trim().length()>0) {
            wrapper.eq("name", medicalVo.getName());
        }

        if (medicalVo.getType() != null && medicalVo.getType().trim().length() > 0) {
            wrapper.eq("type", medicalVo.getType());
        }

        if (medicalVo.getConcept_id() > 0) {
            wrapper.eq("concept_id", medicalVo.getConcept_id());
        }
        List<Medical> medicals = this.list(wrapper);
        return medicals;
    }

    /**
     * 更新或添加医学术语信息
     *
     * @param amendTermVo
     * @return
     */
    public void upsertMedicalInfo(AmendTermVo amendTermVo) {
        MedicalVo medicalVo = new MedicalVo();
        TypeDTO typeDTO;
        Medical medical;
        List<Medical> medicals;

        if (amendTermVo.getMedicalInfo() != null && amendTermVo.getMedicalInfo().size() > 0) {
            for (int i=0; i<amendTermVo.getMedicalInfo().size(); i++) {
                medical = amendTermVo.getMedicalInfo().get(i);

                medicalVo.setName(amendTermVo.getNewterm());
                medicalVo.setType(medical.getType());

                medical.setConcept_id(amendTermVo.getConcept_id());

                medicals = getMedicalInfo(medicalVo);

                if (medicals.size() > 0) {
                    Medical exist_medical = getMedicalInfo(medicalVo).get(0);
                    medical.setId(exist_medical.getId());
                }

                typeDTO = getTypeInfo(medical.getType());

                if (typeDTO != null) {
                    medical.setTypeId(typeDTO.getId());
                }

                this.saveOrUpdate(medical);
            }
        }
    }
    /**
     * 获取术语类型信息
     *
     * @param type
     * @return TypeDTO
     */
    public TypeDTO getTypeInfo(String type) {
        TypeDTO typeDTO = null;
        TypeVo typeVo = new TypeVo();

        try {
            typeVo.setType(type);
            List<TypeDTO> typelist = getTypeId(typeVo);

            if (typelist.size() > 0) {
                typeDTO = getTypeId(typeVo).get(0);
            }
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
        finally {
            return typeDTO;
        }
    }

}
